@@ -24,6 +24,14 @@ class GarbageReader(io.IOBase):
     def tell(self):
         return self.pos
 
+    def seek(self, offset, whence=io.SEEK_SET):
+        if whence == io.SEEK_SET:
+            self.pos = offset
+        elif whence == io.SEEK_CUR:
+            self.pos += offset
+        elif whence == io.SEEK_END:
+            self.pos = self.length - 1 - offset
+
     def read(self, size=None):
         if not size:
             size = self.length - self.tell()
@@ -34,4 +42,4 @@ class GarbageReader(io.IOBase):
         if self.__read_callback:
             self.__read_callback(size)
 
-        return garbage[old_pos:self.pos]
\ No newline at end of file
+        return garbage[old_pos:self.pos]
